# coding: utf-8
from __future__ import absolute_import
from __future__ import unicode_literals

from os.path import abspath
from os.path import dirname
from os.path import join
import re

from pkg_resources import Requirement
from setuptools import setup


_COMMENT_RE = re.compile(r'(^|\s)+#.*$')


def _get_requirements(file_path):
    with open(file_path, 'r') as file:
        for line in file:
            line = _COMMENT_RE.sub('', line)
            line = line.strip()
            if line.startswith('-r '):
                for req in _get_requirements(
                    join(dirname(abspath(file_path)), line[3:])
                ):
                    yield req
            elif line:
                req = Requirement(line)
                req_str = req.name + str(req.specifier)
                if req.marker:
                    req_str += '; ' + str(req.marker)
                yield req_str


def _read(file_name):
    with open(join(dirname(__file__), file_name)) as f:
        return f.read()


def main():
    setup(
        namespace_packages=(
            'edu_to_analytics',
        ),
        name='edu-to-analytics-service',
        version='1.0.1',
        author='БАРС Груп',
        author_email='education_dev@bars-open.ru',
        description=_read('readme.txt'),
        url='https://stash.bars-open.ru/projects/EDUBASE/repos'
            '/edu_to_analytics',
        packages=['edu_to_analytics.service'],
        include_package_data=True,
        install_requires=_get_requirements('requirements.txt'),
    )


if __name__ == '__main__':
    main()
